@@ -7,17 +7,24 @@ import threading
 import pygame
 
 window = Console()
+moprint = Printer()
+moinput = Reader()
 
 
-def __init() -> None:
-    """自动生成控制台界面的函数，不要手动调用
+def init(width, height, font_height, title) -> None:
+    """
+    生成控制台界面
 
+    :param width: 窗口宽（字符）
+    :param height: 窗口高（字符）
+    :param font_height: 字符大小
+    :param title: 窗口标题
     """
     ok = False
 
     def create_console():
         global window
-        window.init(80, 25, 20, 'console')
+        window.init(width, height, font_height, title)
         nonlocal ok
         ok = True
         window.start()
@@ -26,8 +33,6 @@ def __init() -> None:
     thread.start()
     while not ok:
         pygame.time.wait(10)
-
-
-__init()
-moprint = Printer(window)
-moinput = Reader(window, moprint)
+    global window
+    moprint.bind(window)
+    moinput.bind(window, moprint)
